# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class UpdateCustomerDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "customer_name": "str",
        "business_number": "str",
        "domain": "str",
        "address": "str",
        "city": "str",
        "state": "str",
        "country": "str",
        "phone": "str",
        "fax": "str",
        "notes": "str",
        "links": "str",
        "longitude": "float",
        "latitude": "float",
        "zip_code_str": "str",
    }

    attribute_map = {
        "customer_name": "CustomerName",
        "business_number": "BusinessNumber",
        "domain": "Domain",
        "address": "Address",
        "city": "City",
        "state": "State",
        "country": "Country",
        "phone": "Phone",
        "fax": "Fax",
        "notes": "Notes",
        "links": "Links",
        "longitude": "Longitude",
        "latitude": "Latitude",
        "zip_code_str": "ZipCodeStr",
    }

    def __init__(
        self,
        customer_name=None,
        business_number=None,
        domain=None,
        address=None,
        city=None,
        state=None,
        country=None,
        phone=None,
        fax=None,
        notes=None,
        links=None,
        longitude=None,
        latitude=None,
        zip_code_str=None,
        _configuration=None,
    ):  # noqa: E501
        """UpdateCustomerDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._customer_name = None
        self._business_number = None
        self._domain = None
        self._address = None
        self._city = None
        self._state = None
        self._country = None
        self._phone = None
        self._fax = None
        self._notes = None
        self._links = None
        self._longitude = None
        self._latitude = None
        self._zip_code_str = None
        self.discriminator = None

        if customer_name is not None:
            self.customer_name = customer_name
        if business_number is not None:
            self.business_number = business_number
        if domain is not None:
            self.domain = domain
        if address is not None:
            self.address = address
        if city is not None:
            self.city = city
        if state is not None:
            self.state = state
        if country is not None:
            self.country = country
        if phone is not None:
            self.phone = phone
        if fax is not None:
            self.fax = fax
        if notes is not None:
            self.notes = notes
        if links is not None:
            self.links = links
        if longitude is not None:
            self.longitude = longitude
        if latitude is not None:
            self.latitude = latitude
        if zip_code_str is not None:
            self.zip_code_str = zip_code_str

    @property
    def customer_name(self):
        """Gets the customer_name of this UpdateCustomerDTO.  # noqa: E501


        :return: The customer_name of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._customer_name

    @customer_name.setter
    def customer_name(self, customer_name):
        """Sets the customer_name of this UpdateCustomerDTO.


        :param customer_name: The customer_name of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._customer_name = customer_name

    @property
    def business_number(self):
        """Gets the business_number of this UpdateCustomerDTO.  # noqa: E501


        :return: The business_number of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._business_number

    @business_number.setter
    def business_number(self, business_number):
        """Sets the business_number of this UpdateCustomerDTO.


        :param business_number: The business_number of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._business_number = business_number

    @property
    def domain(self):
        """Gets the domain of this UpdateCustomerDTO.  # noqa: E501


        :return: The domain of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this UpdateCustomerDTO.


        :param domain: The domain of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def address(self):
        """Gets the address of this UpdateCustomerDTO.  # noqa: E501


        :return: The address of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this UpdateCustomerDTO.


        :param address: The address of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._address = address

    @property
    def city(self):
        """Gets the city of this UpdateCustomerDTO.  # noqa: E501


        :return: The city of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this UpdateCustomerDTO.


        :param city: The city of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def state(self):
        """Gets the state of this UpdateCustomerDTO.  # noqa: E501


        :return: The state of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this UpdateCustomerDTO.


        :param state: The state of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._state = state

    @property
    def country(self):
        """Gets the country of this UpdateCustomerDTO.  # noqa: E501


        :return: The country of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this UpdateCustomerDTO.


        :param country: The country of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def phone(self):
        """Gets the phone of this UpdateCustomerDTO.  # noqa: E501


        :return: The phone of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._phone

    @phone.setter
    def phone(self, phone):
        """Sets the phone of this UpdateCustomerDTO.


        :param phone: The phone of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._phone = phone

    @property
    def fax(self):
        """Gets the fax of this UpdateCustomerDTO.  # noqa: E501


        :return: The fax of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._fax

    @fax.setter
    def fax(self, fax):
        """Sets the fax of this UpdateCustomerDTO.


        :param fax: The fax of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._fax = fax

    @property
    def notes(self):
        """Gets the notes of this UpdateCustomerDTO.  # noqa: E501


        :return: The notes of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """Sets the notes of this UpdateCustomerDTO.


        :param notes: The notes of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._notes = notes

    @property
    def links(self):
        """Gets the links of this UpdateCustomerDTO.  # noqa: E501


        :return: The links of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._links

    @links.setter
    def links(self, links):
        """Sets the links of this UpdateCustomerDTO.


        :param links: The links of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._links = links

    @property
    def longitude(self):
        """Gets the longitude of this UpdateCustomerDTO.  # noqa: E501


        :return: The longitude of this UpdateCustomerDTO.  # noqa: E501
        :rtype: float
        """
        return self._longitude

    @longitude.setter
    def longitude(self, longitude):
        """Sets the longitude of this UpdateCustomerDTO.


        :param longitude: The longitude of this UpdateCustomerDTO.  # noqa: E501
        :type: float
        """

        self._longitude = longitude

    @property
    def latitude(self):
        """Gets the latitude of this UpdateCustomerDTO.  # noqa: E501


        :return: The latitude of this UpdateCustomerDTO.  # noqa: E501
        :rtype: float
        """
        return self._latitude

    @latitude.setter
    def latitude(self, latitude):
        """Sets the latitude of this UpdateCustomerDTO.


        :param latitude: The latitude of this UpdateCustomerDTO.  # noqa: E501
        :type: float
        """

        self._latitude = latitude

    @property
    def zip_code_str(self):
        """Gets the zip_code_str of this UpdateCustomerDTO.  # noqa: E501


        :return: The zip_code_str of this UpdateCustomerDTO.  # noqa: E501
        :rtype: str
        """
        return self._zip_code_str

    @zip_code_str.setter
    def zip_code_str(self, zip_code_str):
        """Sets the zip_code_str of this UpdateCustomerDTO.


        :param zip_code_str: The zip_code_str of this UpdateCustomerDTO.  # noqa: E501
        :type: str
        """

        self._zip_code_str = zip_code_str

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UpdateCustomerDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpdateCustomerDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UpdateCustomerDTO):
            return True

        return self.to_dict() != other.to_dict()
