# coding: utf-8

"""
    Welcome to the Atera API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from atera_client.configuration import Configuration


class CreateTicketDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "ticket_title": "str",
        "description": "str",
        "ticket_priority": "str",
        "ticket_impact": "str",
        "ticket_status": "str",
        "ticket_type": "str",
        "end_user_id": "int",
        "end_user_first_name": "str",
        "end_user_last_name": "str",
        "end_user_email": "str",
        "technician_contact_id": "int",
    }

    attribute_map = {
        "ticket_title": "TicketTitle",
        "description": "Description",
        "ticket_priority": "TicketPriority",
        "ticket_impact": "TicketImpact",
        "ticket_status": "TicketStatus",
        "ticket_type": "TicketType",
        "end_user_id": "EndUserID",
        "end_user_first_name": "EndUserFirstName",
        "end_user_last_name": "EndUserLastName",
        "end_user_email": "EndUserEmail",
        "technician_contact_id": "TechnicianContactID",
    }

    def __init__(
        self,
        ticket_title=None,
        description=None,
        ticket_priority=None,
        ticket_impact=None,
        ticket_status=None,
        ticket_type=None,
        end_user_id=None,
        end_user_first_name=None,
        end_user_last_name=None,
        end_user_email=None,
        technician_contact_id=None,
        _configuration=None,
    ):  # noqa: E501
        """CreateTicketDTO - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._ticket_title = None
        self._description = None
        self._ticket_priority = None
        self._ticket_impact = None
        self._ticket_status = None
        self._ticket_type = None
        self._end_user_id = None
        self._end_user_first_name = None
        self._end_user_last_name = None
        self._end_user_email = None
        self._technician_contact_id = None
        self.discriminator = None

        self.ticket_title = ticket_title
        self.description = description
        if ticket_priority is not None:
            self.ticket_priority = ticket_priority
        if ticket_impact is not None:
            self.ticket_impact = ticket_impact
        if ticket_status is not None:
            self.ticket_status = ticket_status
        if ticket_type is not None:
            self.ticket_type = ticket_type
        if end_user_id is not None:
            self.end_user_id = end_user_id
        if end_user_first_name is not None:
            self.end_user_first_name = end_user_first_name
        if end_user_last_name is not None:
            self.end_user_last_name = end_user_last_name
        if end_user_email is not None:
            self.end_user_email = end_user_email
        if technician_contact_id is not None:
            self.technician_contact_id = technician_contact_id

    @property
    def ticket_title(self):
        """Gets the ticket_title of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_title of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_title

    @ticket_title.setter
    def ticket_title(self, ticket_title):
        """Sets the ticket_title of this CreateTicketDTO.


        :param ticket_title: The ticket_title of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and ticket_title is None:
            raise ValueError("Invalid value for `ticket_title`, must not be `None`")  # noqa: E501

        self._ticket_title = ticket_title

    @property
    def description(self):
        """Gets the description of this CreateTicketDTO.  # noqa: E501


        :return: The description of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTicketDTO.


        :param description: The description of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def ticket_priority(self):
        """Gets the ticket_priority of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_priority of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_priority

    @ticket_priority.setter
    def ticket_priority(self, ticket_priority):
        """Sets the ticket_priority of this CreateTicketDTO.


        :param ticket_priority: The ticket_priority of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Low", "Medium", "High", "Critical"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_priority not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_priority` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_priority, allowed_values
                )
            )

        self._ticket_priority = ticket_priority

    @property
    def ticket_impact(self):
        """Gets the ticket_impact of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_impact of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_impact

    @ticket_impact.setter
    def ticket_impact(self, ticket_impact):
        """Sets the ticket_impact of this CreateTicketDTO.


        :param ticket_impact: The ticket_impact of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["NoImpact", "SiteDown", "ServerIssue", "Minor", "Major", "Crisis"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_impact not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_impact` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_impact, allowed_values
                )
            )

        self._ticket_impact = ticket_impact

    @property
    def ticket_status(self):
        """Gets the ticket_status of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_status of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_status

    @ticket_status.setter
    def ticket_status(self, ticket_status):
        """Sets the ticket_status of this CreateTicketDTO.


        :param ticket_status: The ticket_status of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._ticket_status = ticket_status

    @property
    def ticket_type(self):
        """Gets the ticket_type of this CreateTicketDTO.  # noqa: E501


        :return: The ticket_type of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._ticket_type

    @ticket_type.setter
    def ticket_type(self, ticket_type):
        """Sets the ticket_type of this CreateTicketDTO.


        :param ticket_type: The ticket_type of this CreateTicketDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Incident", "Problem", "Request", "Change"]  # noqa: E501
        if self._configuration.client_side_validation and ticket_type not in allowed_values:
            raise ValueError(
                "Invalid value for `ticket_type` ({0}), must be one of {1}".format(  # noqa: E501
                    ticket_type, allowed_values
                )
            )

        self._ticket_type = ticket_type

    @property
    def end_user_id(self):
        """Gets the end_user_id of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_id of this CreateTicketDTO.  # noqa: E501
        :rtype: int
        """
        return self._end_user_id

    @end_user_id.setter
    def end_user_id(self, end_user_id):
        """Sets the end_user_id of this CreateTicketDTO.


        :param end_user_id: The end_user_id of this CreateTicketDTO.  # noqa: E501
        :type: int
        """

        self._end_user_id = end_user_id

    @property
    def end_user_first_name(self):
        """Gets the end_user_first_name of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_first_name of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_first_name

    @end_user_first_name.setter
    def end_user_first_name(self, end_user_first_name):
        """Sets the end_user_first_name of this CreateTicketDTO.


        :param end_user_first_name: The end_user_first_name of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_first_name = end_user_first_name

    @property
    def end_user_last_name(self):
        """Gets the end_user_last_name of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_last_name of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_last_name

    @end_user_last_name.setter
    def end_user_last_name(self, end_user_last_name):
        """Sets the end_user_last_name of this CreateTicketDTO.


        :param end_user_last_name: The end_user_last_name of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_last_name = end_user_last_name

    @property
    def end_user_email(self):
        """Gets the end_user_email of this CreateTicketDTO.  # noqa: E501


        :return: The end_user_email of this CreateTicketDTO.  # noqa: E501
        :rtype: str
        """
        return self._end_user_email

    @end_user_email.setter
    def end_user_email(self, end_user_email):
        """Sets the end_user_email of this CreateTicketDTO.


        :param end_user_email: The end_user_email of this CreateTicketDTO.  # noqa: E501
        :type: str
        """

        self._end_user_email = end_user_email

    @property
    def technician_contact_id(self):
        """Gets the technician_contact_id of this CreateTicketDTO.  # noqa: E501


        :return: The technician_contact_id of this CreateTicketDTO.  # noqa: E501
        :rtype: int
        """
        return self._technician_contact_id

    @technician_contact_id.setter
    def technician_contact_id(self, technician_contact_id):
        """Sets the technician_contact_id of this CreateTicketDTO.


        :param technician_contact_id: The technician_contact_id of this CreateTicketDTO.  # noqa: E501
        :type: int
        """

        self._technician_contact_id = technician_contact_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict()) if hasattr(item[1], "to_dict") else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CreateTicketDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTicketDTO):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTicketDTO):
            return True

        return self.to_dict() != other.to_dict()
